@@ -1,22 +1,17 @@
 package Mite::App::Command::clean;
-
-use feature ':5.10';
-use Mouse;
-use MouseX::Foreign;
+use Mite::MyMoo;
 extends qw(Mite::App::Command);
 
-use Method::Signatures;
-use Path::Tiny;
-use Carp;
-
-method abstract() {
+sub abstract {
     return "Remove compiled mite files";
 }
 
-method execute($opts, $args) {
+sub execute {
+    my ( $self, $opts, $args ) = ( shift, @_ );
+
     return if $self->should_exit_quietly($opts); 
 
-   require Mite::Project;
+    require Mite::Project;
     my $project = Mite::Project->default;
     $project->clean_mites;
     $project->clean_shim;
