@@ -56,6 +56,19 @@ sub compile {
         $code .= $class->compile;
     }
 
+    my $tidied;
+    eval {
+        my $flag;
+        if ( $self->source->project->config->should_tidy ) {
+            $flag = Perl::Tidy::perltidy(
+                source      => \$code,
+                destination => \$tidied,
+                argv        => [],
+            );
+        }
+        !$flag;
+    } and length($tidied) and ( $code = $tidied );
+
     return $code;
 }
 
